@@ -364,7 +364,8 @@ impl GeneralReadout for LinuxGeneralReadout {
         if ret != -1 {
             let f_load = 1f64 / (1 << libc::SI_LOAD_SHIFT) as f64;
             let cpu_usage = info.loads[0] as f64 * f_load;
-            let cpu_usage_u = (cpu_usage / num_cpus::get() as f64 * 100.0).round() as usize;
+            let cpu_usage_u =
+                (cpu_usage / self.cpu_cores().unwrap() as f64 * 100.0).round() as usize;
             Ok(cpu_usage_u as usize)
         } else {
             Err(ReadoutError::Other(
@@ -374,11 +375,28 @@ impl GeneralReadout for LinuxGeneralReadout {
     }
 
     fn cpu_physical_cores(&self) -> Result<usize, ReadoutError> {
-        crate::shared::cpu_physical_cores()
+        use std::io::{BufRead, BufReader};
+        if let Ok(content) = fs::File::open("/proc/cpuinfo") {
+            let reader = BufReader::new(content);
+            for line in reader.lines().flatten() {
+                if line.to_lowercase().starts_with("cpu cores") {
+                    let cores = line
+                        .split(':')
+                        .nth(1)
+                        .unwrap()
+                        .trim()
+                        .parse::<usize>()
+                        .unwrap();
+                    return Ok(cores);
+                }
+            }
+        }
+
+        Err(ReadoutError::MetricNotAvailable)
     }
 
     fn cpu_cores(&self) -> Result<usize, ReadoutError> {
-        crate::shared::cpu_cores()
+        Ok(unsafe { libc::sysconf(libc::_SC_NPROCESSORS_CONF) } as usize)
     }
 
     fn uptime(&self) -> Result<usize, ReadoutError> {
