@@ -134,16 +134,16 @@ impl GeneralReadout for WindowsGeneralReadout {
         unsafe { GetUserNameA(PSTR(std::ptr::null_mut()), &mut size) };
 
         if size == 0 {
-            return Err(ReadoutError::Other(String::from(
-                "Call to \"GetUserNameA\" failed.",
-            )));
+            return Err(ReadoutError::Other(
+                "Call to \"GetUserNameA\" failed.".to_string(),
+            ));
         }
 
         let mut username = Vec::with_capacity(size as usize);
         if !unsafe { GetUserNameA(PSTR(username.as_mut_ptr()), &mut size) }.as_bool() {
-            return Err(ReadoutError::Other(String::from(
-                "Call to \"GetUserNameA\" failed.",
-            )));
+            return Err(ReadoutError::Other(
+                "Call to \"GetUserNameA\" failed.".to_string(),
+            ));
         }
 
         unsafe {
@@ -215,7 +215,24 @@ impl GeneralReadout for WindowsGeneralReadout {
     }
 
     fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
-        crate::shared::local_ip(interface)
+        match interface {
+            Some(it) => {
+                if let Ok(addresses) = local_ip_address::list_afinet_netifas() {
+                    if let Some((_, ip)) = local_ip_address::find_ifa(addresses, &it) {
+                        return Ok(ip.to_string());
+                    }
+                }
+            }
+            None => {
+                if let Ok(local_ip) = local_ip_address::local_ip() {
+                    return Ok(local_ip.to_string());
+                }
+            }
+        };
+
+        Err(ReadoutError::Other(
+            "Unable to get local IP address.".to_string(),
+        ))
     }
 
     fn cpu_model_name(&self) -> Result<String, ReadoutError> {
